@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.91'; # VERSION
+our $VERSION = '1.92'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -87,30 +87,18 @@ sub gather_file_travis_yml
   my $file = Dist::Zilla::File::InMemory->new({
     name    => '.travis.yml',
     content => join("\n", q{language: perl},
+                          q{sudo: false},
                           q{},
-                          q{# remember need at least one install command, even if there are no},
-                          q{# prereqs, else travis will try to install deps using cpanm},
-                          q{# which is not what we want since this is a Dist::Zilla dist.},
                           q{install:},
-                          q{  - cpanm -n Dist::Zilla},
+                          q{  - perlbrew list},
                           q{  - dzil authordeps --missing | cpanm -n},
-                          q{  - cpanm -n Pod::Find Test::CPAN::Changes Test::EOL Test::Fixme Test::NoTabs Test::Pod::Spelling::CommonMistakes Test::Spelling Test::Strict Test::Version || true},
-                          q{#  - cpanm -n Foo::Bar},
+                          q{  - dzil listdeps   --missing | cpanm -n},
                           q{},
                           q{perl:},
-                          (map { "  - \"5.$_\""} qw( 8 10 12 14 16 18 20 )),
-                          q{},
-                          q{#env:},
-                          q{#  - FOO=bar},
-                          q{},
-                          q{#before_script: /bin/true},
+                          (map { "  - \"5.$_\""} qw( 8 10 12 14 16 18 20 22 )),
                           q{},
                           q{script:},
                           q{  - dzil test -v},
-                          q{},
-                          q{#after_script: /bin/true},
-                          q{},
-                          q{sudo: false},
     ),
   });
 
@@ -328,7 +316,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.91
+version 1.92
 
 =head1 DESCRIPTION
 
