@@ -7,14 +7,14 @@ use File::Path qw( make_path );
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '1.91'; # VERSION
+our $VERSION = '1.92'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeBuild';
 with 'Dist::Zilla::Role::InstallTool';
 with 'Dist::Zilla::Role::TestRunner';
 
-sub mvp_multivalue_args { qw( diag ) }
+sub mvp_multivalue_args { qw( diag diag_preamble ) }
 
 has source => (
   is      =>'ro',
@@ -32,6 +32,17 @@ has diag => (
   default => sub { [] },
 );
 
+has diag_preamble => (
+  is      => 'ro',
+  default => sub { [] },
+);
+
+has _diag_content => (
+  is      => 'rw',
+  isa     => 'Str',
+  default => '',
+);
+
 sub before_build
 {
   my($self) = @_;
@@ -71,7 +82,9 @@ sub before_build
   }
   
   my $diag = $self->zilla->root->file(qw( t 00_diag.t ));
-  $diag->spew(scalar $source->parent->parent->file('t', '00_diag.t')->absolute->slurp);
+  my $content = $source->parent->parent->file('t', '00_diag.t')->absolute->slurp;
+  $content =~ s{## PREAMBLE ##}{join "\n", map { s/^\| //; $_ } @{ $self->diag_preamble }}e;
+  $self->_diag_content($content);
 }
 
 # not really an installer, but we have to create a list
@@ -118,12 +131,18 @@ sub setup_installer
     }
   }
   
-  my $content = join "\n", sort keys %list;
-  $content .= "\n";
+  my $code = '';
   
-  $self->zilla->root->file('t', '00_diag.txt')->spew($content);
+  $code = "BEGIN { eval q{ use EV; } }\n" if $list{EV};
+  $code .= '$modules{$_} = $_ for qw(' . "\n";
+  $code .= join "\n", map { "  $_" } sort keys %list;
+  $code .= "\n);\n";
   
-  my($file) = grep { $_->name eq 't/00_diag.txt' } @{ $self->zilla->files };
+  my($file) = grep { $_->name eq 't/00_diag.t' } @{ $self->zilla->files };
+
+  my $content = $self->_diag_content;
+  $content =~ s{## GENERATE ##}{$code};
+
   if($file)
   {
     $file->content($content);
@@ -131,29 +150,14 @@ sub setup_installer
   else
   {
     $file = Dist::Zilla::File::InMemory->new({
-      name    => 't/00_diag.txt',
-      content => $content,
+      name => 't/00_diag.t',
+      content => $content
     });
     $self->add_file($file);
   }
-  
-  if($list{EV})
-  {
-    $self->zilla->root->file('t', '00_diag.pre.txt')->spew("EV\n");
-    my($file) = grep { $_->name eq 't/00_diag.pre.txt' } @{ $self->zilla->files };
-    if($file)
-    {
-      $file->content("EV\n");
-    }
-    else
-    {
-      $file = Dist::Zilla::File::InMemory->new({
-        name    => '00_diag.pre.txt',
-        content => "EV\n",
-      });
-      $self->add_file($file);
-    }
-  }
+
+  my $diag = $self->zilla->root->file(qw( t 00_diag.t ));
+  $diag->spew($content);
 }
 
 sub test
@@ -179,7 +183,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 1.91
+version 1.92
 
 =head1 SYNOPSIS
 
