@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.91'; # VERSION
+our $VERSION = '1.92'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -23,6 +23,7 @@ sub mvp_multivalue_args { qw(
   alien_helper
   upgrade
   preamble
+  diag_preamble
   
   diag
   allow_dirty ) }
@@ -146,8 +147,9 @@ sub configure
   {
     $self->add_plugins([
       'Author::Plicease::Tests' => {
-        maybe skip => $self->payload->{release_tests_skip},
-        maybe diag => $self->payload->{diag},
+        maybe skip          => $self->payload->{release_tests_skip},
+        maybe diag          => $self->payload->{diag},
+        maybe diag_preamble => $self->payload->{diag_preamble},
       }
     ]);
   }
@@ -234,10 +236,10 @@ sub configure
       die "travis is trying to test Perl 5.19";
     }
     
-    unless(exists $travis->{perl} && grep /^5\.20$/, @{ $travis->{perl} })
+    unless(exists $travis->{perl} && grep /^5\.22$/, @{ $travis->{perl} })
     {
       print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-      print STDERR "travis is not testing Perl 5.20";
+      print STDERR "travis is not testing Perl 5.22";
       print STDERR Term::ANSIColor::color('reset') if -t STDERR;
       print STDERR "\n";
     }
@@ -250,6 +252,17 @@ sub configure
       print STDERR "\n";
     }
   }
+
+  foreach my $name (qw( t/00_diag.txt t/00_diag.pre.txt xt/release/build_environment.t xt/release/unused.t ))
+  {  
+    if(-e $name)
+    {
+      print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
+      print STDERR "You have a lingering deprecated test: $name";
+      print STDERR Term::ANSIColor::color('reset') if -t STDERR;
+      print STDERR "\n";
+    }
+  }
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -268,7 +281,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.91
+version 1.92
 
 =head1 SYNOPSIS
 
